@@ -55,6 +55,7 @@
 #include <QtSensors/qgyroscope.h>
 #include <QtSensors/qirproximitysensor.h>
 #include <QtSensors/qtiltsensor.h>
+#include <QtSensors/qlidsensor.h>
 
 #include "qmlsensorglobal.h"
 #include "qmlsensor.h"
@@ -75,6 +76,7 @@
 #include "qmltapsensor.h"
 #include "qmltiltsensor.h"
 #include "qmlsensorgesture.h"
+#include "qmllidsensor.h"
 
 static void initResources()
 {
@@ -222,11 +224,11 @@ public:
 
         qmlRegisterType           <QmlSensorGesture            >(package, major, minor, "SensorGesture");
 
-        // Register the 5.8 interfaces
-        // No API changes, just reintroduce existing interfaces from 5.2
-        // Implicitly registers 5.3 - 5.7 too
-        minor = 8;
-        qmlRegisterType           <QmlAltimeter                >(package, major, minor, "Altimeter");
+        // Register the new 5.9 interfaces
+        // Implicitly registers 5.3 - 5.8 too
+        minor = 9;
+        qmlRegisterType           <QmlLidSensor                >(package, major, minor, "LidSensor");
+        qmlRegisterUncreatableType<QmlLidReading               >(package, major, minor, "LidReading",          QLatin1String("Cannot create LidReading"));
     }
 };
 
