@@ -76,7 +76,13 @@ IMPLEMENT_READING(QMagnetometerReading)
     The accuracy of each reading is measured as a number from 0 to 1.
     A value of 1 is the highest level that the device can support and 0 is
     the worst.
-    \sa {http://wiki.forum.nokia.com/index.php/CS001671_-_Calibrating_the_magnetometer_sensor}{CS001671 - Calibrating the magnetometer sensor}
+
+    \section2 Calibration
+    If the device is reporting low accuracy, then calibration might be needed before acceptable measurements
+    can be provided.
+    Basic calibration can usually be done by either rotating your device in a figure of eight, or by
+    rotating the device along each of its three axes. For more information, check your device's
+    documentation on how to calibrate the magnetic sensor.
 */
 
 /*!
@@ -150,7 +156,7 @@ void QMagnetometerReading::setZ(qreal z)
 
     Note that this only changes when measuring geomagnetic flux density.
     Raw magnetic flux readings will always have a value of 1.
-    \sa {QMagnetometerReading Units}, {http://wiki.forum.nokia.com/index.php/CS001671_-_Calibrating_the_magnetometer_sensor}{CS001671 - Calibrating the magnetometer sensor}
+    \sa {QMagnetometerReading Units}, {Calibration}
 */
 
 qreal QMagnetometerReading::calibrationLevel() const
